@@ -338,7 +338,7 @@ public class ParseCamt05200107 extends AbstractCamtParser
         if(report.getBal().size()>0){
             CashBalance8 firstBal = report.getBal().get(0);
             String firstCode = firstBal.getTp().getCdOrPrtry().getCd();
-            if(firstCode.equalsIgnoreCase("PRCD") || firstCode.equalsIgnoreCase("ITBD")) {
+            if(firstCode.equalsIgnoreCase("PRCD") || firstCode.equalsIgnoreCase("ITBD") || firstCode.equalsIgnoreCase("OPBD")) {
                 tag.start.value = new Value(this.checkDebit(firstBal.getAmt().getValue(),firstBal.getCdtDbtInd()));
                 tag.start.value.setCurr(firstBal.getAmt().getCcy());
                 if(firstCode.equalsIgnoreCase("PRCD") ){
