@@ -159,8 +159,17 @@ public final class HBCIHandler
             this.passport.setParentHandlerData(this);
 
             if (!lazyInit) {
+              
+              if (Feature.INIT_FLIP_USER_INST.isEnabled())
+              {
+                registerUser();
+                registerInstitute();
+              }
+              else
+              {
                 registerInstitute();
                 registerUser();
+              }
             }
 
             if (!passport.getHBCIVersion().equals(hbciversion)) {
@@ -201,8 +210,17 @@ public final class HBCIHandler
             try {
                 HBCIUtils.log("hbci thread: starting init()",HBCIUtils.LOG_DEBUG);
 
-                registerInstitute();
-                registerUser();
+                if (Feature.INIT_FLIP_USER_INST.isEnabled())
+                {
+                  registerUser();
+                  registerInstitute();
+                }
+                else
+                {
+                  registerInstitute();
+                  registerUser();
+                }
+                
                 sync_main.setData("execStatus",null);
             } catch (Exception e) {
                 // im fehlerfall muss sicherheitshalber ein noch
